package com.pdaaphm.system.service.impl;

import java.util.List;
import com.pdaaphm.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.pdaaphm.system.mapper.AlgConfigMapper;
import com.pdaaphm.system.domain.AlgConfig;
import com.pdaaphm.system.service.IAlgConfigService;

/**
 * 算法配置Service业务层处理
 * 
 * @author Allen
 * @date 2024-08-19
 */
@Service
public class AlgConfigServiceImpl implements IAlgConfigService 
{
    @Autowired
    private AlgConfigMapper algConfigMapper;

    /**
     * 查询算法配置
     * 
     * @param id 算法配置主键
     * @return 算法配置
     */
    @Override
    public AlgConfig selectAlgConfigById(Long id)
    {
        return algConfigMapper.selectAlgConfigById(id);
    }

    /**
     * 查询算法配置列表
     * 
     * @param algConfig 算法配置
     * @return 算法配置
     */
    @Override
    public List<AlgConfig> selectAlgConfigList(AlgConfig algConfig)
    {
        return algConfigMapper.selectAlgConfigList(algConfig);
    }

    /**
     * 新增算法配置
     * 
     * @param algConfig 算法配置
     * @return 结果
     */
    @Override
    public int insertAlgConfig(AlgConfig algConfig)
    {
        algConfig.setCreateTime(DateUtils.getNowDate());
        return algConfigMapper.insertAlgConfig(algConfig);
    }

    /**
     * 修改算法配置
     * 
     * @param algConfig 算法配置
     * @return 结果
     */
    @Override
    public int updateAlgConfig(AlgConfig algConfig)
    {
        algConfig.setUpdateTime(DateUtils.getNowDate());
        return algConfigMapper.updateAlgConfig(algConfig);
    }

    /**
     * 批量删除算法配置
     * 
     * @param ids 需要删除的算法配置主键
     * @return 结果
     */
    @Override
    public int deleteAlgConfigByIds(Long[] ids)
    {
        return algConfigMapper.deleteAlgConfigByIds(ids);
    }

    /**
     * 删除算法配置信息
     * 
     * @param id 算法配置主键
     * @return 结果
     */
    @Override
    public int deleteAlgConfigById(Long id)
    {
        return algConfigMapper.deleteAlgConfigById(id);
    }

    @Override
    public List<AlgConfig> getAlgConfigByType(String type) {
        AlgConfig algConfig = new AlgConfig();
        algConfig.setAlgType(type);
        return this.selectAlgConfigList(algConfig);
    }
}
